using BingoBrain.Core;

namespace BingoBrain
{
    public static class ModuleBoard
    {
        public static void AutoRegisterModel()
        {
            ModuleBoardk moduleBoardk = ModuleBoardk.Instance;
            moduleBoardk.AddModel(ModelConst.BottomModel, new BottomModel());
            moduleBoardk.AddModel(ModelConst.CallEndModel, new CallEndModel());
            moduleBoardk.AddModel(ModelConst.ChestModel, new ChestModel());
            moduleBoardk.AddModel(ModelConst.SmailModel, new SmailModel());
            moduleBoardk.AddModel(ModelConst.BingoEndModel, new BingoEndModel());
            moduleBoardk.AddModel(ModelConst.ExtraItemModel, new ExtraItemModel());
            moduleBoardk.AddModel(ModelConst.JEffectModel, new JEffectModel());
            moduleBoardk.AddModel(ModelConst.EnterBingoModel, new EnterBingoModel());
            moduleBoardk.AddModel(ModelConst.BingoWhatModel, new BingoWhatModel());
            moduleBoardk.AddModel(ModelConst.JMallModel, new JMallModel());
            moduleBoardk.AddModel(ModelConst.LeaveBingoModel, new LeaveBingoModel());
            moduleBoardk.AddModel(ModelConst.ReadyBingoModel, new ReadyBingoModel());
            moduleBoardk.AddModel(ModelConst.ReadyBingoyModel, new ReadyBingoyModel());
            moduleBoardk.AddModel(ModelConst.BingoHallModel, new BingoHallModel());
            moduleBoardk.AddModel(ModelConst.BingoHalldModel, new BingoHalldModel());
            moduleBoardk.AddModel(ModelConst.SomsionModel, new SomsionModel());
            moduleBoardk.AddModel(ModelConst.MoreCardModel, new MoreCardModel());
            moduleBoardk.AddModel(ModelConst.CheckReadyModel, new CheckReadyModel());
            moduleBoardk.AddModel(ModelConst.BingoStartModel, new BingoStartModel());
            moduleBoardk.AddModel(ModelConst.BingoCardModel, new BingoCardModel());
            moduleBoardk.AddModel(ModelConst.JTermModel, new JTermModel());
            moduleBoardk.AddModel(ModelConst.PropInfoModel, new PropInfoModel());
            moduleBoardk.AddModel(ModelConst.GodPleModel, new GodPleModel());
            moduleBoardk.AddModel(ModelConst.GodPleAcModel, new GodPleAcModel());
            moduleBoardk.AddModel(ModelConst.JTipsModel, new JTipsModel());
            moduleBoardk.AddModel(ModelConst.JThinkModel, new JThinkModel());
            moduleBoardk.AddModel(ModelConst.JTodModel, new JTodModel());
            moduleBoardk.AddModel(ModelConst.BasptModel, new BasptModel());
            moduleBoardk.AddModel(ModelConst.BingoToyModel, new BingoToyModel());
            moduleBoardk.AddModel(ModelConst.StarRewardModel, new StarRewardModel());
            moduleBoardk.AddModel(ModelConst.NetLoadingModel, new NetLoadingModel());

            moduleBoardk.AddModel(ModelConst.FaqUIModel, new FaqUIModel());
            moduleBoardk.AddModel(ModelConst.BroadcastModel, new BroadcastModel());
 
        	moduleBoardk.AddModel(ModelConst.MakeupConfirmModel, new MakeupConfirmModel());
			moduleBoardk.AddModel(ModelConst.SaveingPotModel, new SaveingPotModel());
			moduleBoardk.AddModel(ModelConst.RecordViewModel, new RecordViewModel());
			moduleBoardk.AddModel(ModelConst.FirstRewardModel, new FirstRewardModel());
			moduleBoardk.AddModel(ModelConst.PettyAwardModel, new PettyAwardModel());
			moduleBoardk.AddModel(ModelConst.H5Model, new H5Model());
			moduleBoardk.AddModel(ModelConst.ExchangeModel, new ExchangeModel());
			moduleBoardk.AddModel(ModelConst.PalModel, new PalModel());
			moduleBoardk.AddModel(ModelConst.LoginAModel, new LoginAModel());
		}

        public static void AutoRegisterUIType()
        {
            ModuleBoardk moduleBoardk = ModuleBoardk.Instance;
            moduleBoardk.AddUIType(UIConst.BottomUI, typeof(BottomUI));
            moduleBoardk.AddUIType(UIConst.CallEndUI, typeof(CallEndUI));
            moduleBoardk.AddUIType(UIConst.ChestUI, typeof(ChestUI));
            moduleBoardk.AddUIType(UIConst.SmailUI, typeof(SmailUI));
            moduleBoardk.AddUIType(UIConst.BingoEndUI, typeof(BingoEndUI));
            moduleBoardk.AddUIType(UIConst.ExtraItemUI, typeof(ExtraItemUI));
            moduleBoardk.AddUIType(UIConst.JEffectUI, typeof(JEffectUI));
            moduleBoardk.AddUIType(UIConst.EnterBingoUI, typeof(EnterBingoUI));
            moduleBoardk.AddUIType(UIConst.BingoWhatUI, typeof(BingoWhatUI));
            moduleBoardk.AddUIType(UIConst.JMallUI, typeof(JMallUI));
            moduleBoardk.AddUIType(UIConst.LeaveBingoUI, typeof(LeaveBingoUI));
            moduleBoardk.AddUIType(UIConst.ReadyBingoUI, typeof(ReadyBingoUI));
            moduleBoardk.AddUIType(UIConst.ReadyBingoyUI, typeof(ReadyBingoyUI));
            moduleBoardk.AddUIType(UIConst.BingoHallUI, typeof(BingoHallUI));
            moduleBoardk.AddUIType(UIConst.BingoHalldUI, typeof(BingoHalldUI));
            moduleBoardk.AddUIType(UIConst.SomsionUI, typeof(SomsionUI));
            moduleBoardk.AddUIType(UIConst.MoreCardUI, typeof(MoreCardUI));
            moduleBoardk.AddUIType(UIConst.CheckReadyUI, typeof(CheckReadyUI));
            moduleBoardk.AddUIType(UIConst.BingoStartUI, typeof(BingoStartUI));
            moduleBoardk.AddUIType(UIConst.BingoCardUI, typeof(BingoCardUI));
            moduleBoardk.AddUIType(UIConst.JTermUI, typeof(JTermUI));
            moduleBoardk.AddUIType(UIConst.PropInfoUI, typeof(PropInfoUI));
            moduleBoardk.AddUIType(UIConst.GodPleUI, typeof(GodPleUI));
            moduleBoardk.AddUIType(UIConst.GodPleAcUI, typeof(GodPleAcUI));
            moduleBoardk.AddUIType(UIConst.JTipsUI, typeof(JTipsUI));
            moduleBoardk.AddUIType(UIConst.JThinkUI, typeof(JThinkUI));
            moduleBoardk.AddUIType(UIConst.JTodUI, typeof(JTodUI));
            moduleBoardk.AddUIType(UIConst.BasptUI, typeof(BasptUI));
            moduleBoardk.AddUIType(UIConst.BingoToyUI, typeof(BingoToyUI));
            moduleBoardk.AddUIType(UIConst.StarRewardUI, typeof(StarRewardUI));
            moduleBoardk.AddUIType(UIConst.NetLoadingUI, typeof(NetLoadingUI));

            moduleBoardk.AddUIType(UIConst.FaqUIUI, typeof(FaqUIUI));
            moduleBoardk.AddUIType(UIConst.BroadcastUI, typeof(BroadcastUI));
        	moduleBoardk.AddUIType(UIConst.MakeupConfirmUI, typeof(MakeupConfirmUI));
			moduleBoardk.AddUIType(UIConst.SaveingPotUI, typeof(SaveingPotUI));
			moduleBoardk.AddUIType(UIConst.RecordViewUI, typeof(RecordViewUI));
			moduleBoardk.AddUIType(UIConst.FirstRewardUI, typeof(FirstRewardUI));
			moduleBoardk.AddUIType(UIConst.PettyAwardUI, typeof(PettyAwardUI));
			moduleBoardk.AddUIType(UIConst.H5UI, typeof(H5UI));
			moduleBoardk.AddUIType(UIConst.ExchangeUI, typeof(ExchangeUI));
			moduleBoardk.AddUIType(UIConst.PalUI, typeof(PalUI));
			moduleBoardk.AddUIType(UIConst.LoginAUI, typeof(LoginAUI));
		}

        public static void AutoRegisterCtrl()
        {
            ModuleBoardk moduleBoardk = ModuleBoardk.Instance;
            moduleBoardk.AddCtrl(CtrlConst.BottomCtrl, new BottomCtrl());
            moduleBoardk.AddCtrl(CtrlConst.CallEndCtrl, new CallEndCtrl());
            moduleBoardk.AddCtrl(CtrlConst.ChestCtrl, new ChestCtrl());
            moduleBoardk.AddCtrl(CtrlConst.SmailCtrl, new SmailCtrl());
            moduleBoardk.AddCtrl(CtrlConst.BingoEndCtrl, new BingoEndCtrl());
            moduleBoardk.AddCtrl(CtrlConst.ExtraItemCtrl, new ExtraItemCtrl());
            moduleBoardk.AddCtrl(CtrlConst.JEffectCtrl, new JEffectCtrl());
            moduleBoardk.AddCtrl(CtrlConst.EnterBingoCtrl, new EnterBingoCtrl());
            moduleBoardk.AddCtrl(CtrlConst.BingoWhatCtrl, new BingoWhatCtrl());
            moduleBoardk.AddCtrl(CtrlConst.JMallCtrl, new JMallCtrl());
            moduleBoardk.AddCtrl(CtrlConst.LeaveBingoCtrl, new LeaveBingoCtrl());
            moduleBoardk.AddCtrl(CtrlConst.ReadyBingoCtrl, new ReadyBingoCtrl());
            moduleBoardk.AddCtrl(CtrlConst.ReadyBingoyCtrl, new ReadyBingoyCtrl());
            moduleBoardk.AddCtrl(CtrlConst.BingoHallCtrl, new BingoHallCtrl());
            moduleBoardk.AddCtrl(CtrlConst.BingoHalldCtrl, new BingoHalldCtrl());
            moduleBoardk.AddCtrl(CtrlConst.SomsionCtrl, new SomsionCtrl());
            moduleBoardk.AddCtrl(CtrlConst.MoreCardCtrl, new MoreCardCtrl());
            moduleBoardk.AddCtrl(CtrlConst.CheckReadyCtrl, new CheckReadyCtrl());
            moduleBoardk.AddCtrl(CtrlConst.BingoStartCtrl, new BingoStartCtrl());
            moduleBoardk.AddCtrl(CtrlConst.BingoCardCtrl, new BingoCardCtrl());
            moduleBoardk.AddCtrl(CtrlConst.JTermCtrl, new JTermCtrl());
            moduleBoardk.AddCtrl(CtrlConst.PropInfoCtrl, new PropInfoCtrl());
            moduleBoardk.AddCtrl(CtrlConst.GodPleCtrl, new GodPleCtrl());
            moduleBoardk.AddCtrl(CtrlConst.GodPleAcCtrl, new GodPleAcCtrl());
            moduleBoardk.AddCtrl(CtrlConst.JTipsCtrl, new JTipsCtrl());
            moduleBoardk.AddCtrl(CtrlConst.JThinkCtrl, new JThinkCtrl());
            moduleBoardk.AddCtrl(CtrlConst.JTodCtrl, new JTodCtrl());
            moduleBoardk.AddCtrl(CtrlConst.BasptCtrl, new BasptCtrl());
            moduleBoardk.AddCtrl(CtrlConst.BingoToyCtrl, new BingoToyCtrl());
            moduleBoardk.AddCtrl(CtrlConst.PrenterCtrl, new PrenterCtrl());
            moduleBoardk.AddCtrl(CtrlConst.StarRewardCtrl, new StarRewardCtrl());
            moduleBoardk.AddCtrl(CtrlConst.NetLoadingCtrl, new NetLoadingCtrl());

            moduleBoardk.AddCtrl(CtrlConst.FaqUICtrl, new FaqUICtrl());
            moduleBoardk.AddCtrl(CtrlConst.BroadcastCtrl, new BroadcastCtrl());
        	moduleBoardk.AddCtrl(CtrlConst.MakeupConfirmCtrl, new MakeupConfirmCtrl());
			moduleBoardk.AddCtrl(CtrlConst.SaveingPotCtrl, new SaveingPotCtrl());
			moduleBoardk.AddCtrl(CtrlConst.RecordViewCtrl, new RecordViewCtrl());
			moduleBoardk.AddCtrl(CtrlConst.FirstRewardCtrl, new FirstRewardCtrl());
			moduleBoardk.AddCtrl(CtrlConst.PettyAwardCtrl, new PettyAwardCtrl());
			moduleBoardk.AddCtrl(CtrlConst.H5Ctrl, new H5Ctrl());
			moduleBoardk.AddCtrl(CtrlConst.ExchangeCtrl, new ExchangeCtrl());
			moduleBoardk.AddCtrl(CtrlConst.PalCtrl, new PalCtrl());
			moduleBoardk.AddCtrl(CtrlConst.LoginACtrl, new LoginACtrl());
		}

        public static void AutoRegisterUICtrl()
        {
            ModuleBoardk moduleBoardk = ModuleBoardk.Instance;
            moduleBoardk.AddUICtrl(UICtrlConst.BottomUICtrl, new BottomUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.CallEndUICtrl, new CallEndUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.ChestUICtrl, new ChestUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.SmailUICtrl, new SmailUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BingoEndUICtrl, new BingoEndUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.ExtraItemUICtrl, new ExtraItemUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.JEffectUICtrl, new JEffectUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.EnterBingoUICtrl, new EnterBingoUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BingoWhatUICtrl, new BingoWhatUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.JMallUICtrl, new JMallUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.LeaveBingoUICtrl, new LeaveBingoUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.ReadyBingoUICtrl, new ReadyBingoUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.ReadyBingoyUICtrl, new ReadyBingoyUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BingoHallUICtrl, new BingoHallUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BingoHalldUICtrl, new BingoHalldUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.SomsionUICtrl, new SomsionUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.MoreCardUICtrl, new MoreCardUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.CheckReadyUICtrl, new CheckReadyUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BingoStartUICtrl, new BingoStartUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BingoCardUICtrl, new BingoCardUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.JTermUICtrl, new JTermUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.PropInfoUICtrl, new PropInfoUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.GodPleUICtrl, new GodPleUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.GodPleAcUICtrl, new GodPleAcUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.JTipsUICtrl, new JTipsUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.JThinkUICtrl, new JThinkUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.JTodUICtrl, new JTodUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BasptUICtrl, new BasptUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BingoToyUICtrl, new BingoToyUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.StarRewardUICtrl, new StarRewardUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.NetLoadingUICtrl, new NetLoadingUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.FaqUIUICtrl, new FaqUIUICtrl());
            moduleBoardk.AddUICtrl(UICtrlConst.BroadcastUICtrl, new BroadcastUICtrl());


        	moduleBoardk.AddUICtrl(UICtrlConst.MakeupConfirmUICtrl, new MakeupConfirmUICtrl());
			moduleBoardk.AddUICtrl(UICtrlConst.SaveingPotUICtrl, new SaveingPotUICtrl());
			moduleBoardk.AddUICtrl(UICtrlConst.RecordViewUICtrl, new RecordViewUICtrl());
			moduleBoardk.AddUICtrl(UICtrlConst.FirstRewardUICtrl, new FirstRewardUICtrl());
			moduleBoardk.AddUICtrl(UICtrlConst.PettyAwardUICtrl, new PettyAwardUICtrl());
			moduleBoardk.AddUICtrl(UICtrlConst.H5UICtrl, new H5UICtrl());
			moduleBoardk.AddUICtrl(UICtrlConst.ExchangeUICtrl, new ExchangeUICtrl());
			moduleBoardk.AddUICtrl(UICtrlConst.PalUICtrl, new PalUICtrl());
			moduleBoardk.AddUICtrl(UICtrlConst.LoginAUICtrl, new LoginAUICtrl());
		}
    }
}